@@ -28,6 +28,9 @@
 /* make the startcode, etc. dynamic aware ({con,de}structors) */
 /* #define WANT_DYNAMIC */
 
+/* GDB support in the dynamic linker */
+#define WANT_LD_SO_GDB_SUPPORT
+
 /* do you want smaller or faster string routines? */
 /* #define WANT_FASTER_STRING_ROUTINES */
 
@@ -35,11 +38,9 @@
  * string */
 /* #define WANT_FULL_POSIX_COMPAT */
 
-/* read the comment in lib/strncat.c for an explanation */
-/* #define WANT_NON_COMPLIANT_STRNCAT */
-
 /* on i386, Linux has an alternate syscall method since 2002/12/16 */
 /* on my Athlon XP, it is twice as fast, but it's only in kernel 2.5 */
+/* 20040118: enabling this breaks User Mode Linux!  It's their fault. */
 #define WANT_SYSENTER
 
 #define WANT_LINKER_WARNINGS
@@ -84,12 +85,20 @@
  * See http://www.fefe.de/ipv6pnpdns.html */
 // #define WANT_IPV6_PLUGPLAY_DNS
 
-/* dy you want that malloc(0) return a pointer to a "zero-length" object
+/* do you want that malloc(0) return a pointer to a "zero-length" object
  * that is realloc-able; means realloc(..,size) gives a NEW object (like a
  * call to malloc(size)).
  * WARNING: this violates C99 */
 /* #define WANT_MALLOC_ZERO */
 
+/* This enables a stack gap.  Basically, the start code does not run
+ * main but stackgap, which then does alloca(random()) and calls main.
+ * The effect is that buffer overflow exploits will no longer be able to
+ * know the address of the buffer.  Cost: 62 bytes code on x86. */
+/* WARNING: this appears to break with some binutils versions.  Works
+ * for me with binutils 2.15.  The symptom is an error message that
+ * `main' can not be found. */
+#define WANT_STACKGAP
 
 /* stop uncommenting here ;-) */
 #ifndef WANT_FASTER_STRING_ROUTINES
