@@ -3,6 +3,8 @@
 
 #include <sys/cdefs.h>
 
+__BEGIN_DECLS
+
 extern int isascii (int c) __THROW __attribute__ ((__const__));
 extern int isblank (int c) __THROW __attribute__ ((__const__));
 extern int isalnum (int c) __THROW __attribute__ ((__const__));
@@ -25,4 +27,6 @@ extern int isxdigit(int c) __THROW __attribute__ ((__const__));
 
 extern int isgraph(int c) __THROW __attribute__ ((__const__));
 
+__END_DECLS
+
 #endif
