@@ -1,8 +1,11 @@
 #ifndef _STDARG_H
 #define _STDARG_H
 
+#include <sys/cdefs.h>
 #include <endian.h>
 
+__BEGIN_DECLS
+
 #if (__GNUC__ > 2) || ((__GNUC__ == 2) && (__GNUC_MINOR__ >= 96))
 
 typedef __builtin_va_list va_list;
@@ -21,4 +24,6 @@ typedef __builtin_va_list va_list;
 #define va_copy(d,s)	__va_copy(d,s)
 #endif
 
+__END_DECLS
+
 #endif
