@@ -26,7 +26,7 @@ __BEGIN_DECLS
 #define PT_TRACE_ME		PTRACE_TRACEME
 #define PT_READ_I		PTRACE_PEEKTEXT
 #define PT_READ_D		PTRACE_PEEKDATA
-#define PT_READ_U		PTRACE_READ_U
+#define PT_READ_U		PTRACE_PEEKUSER
 #define PT_WRITE_I		PTRACE_POKETEXT
 #define PT_WRITE_D		PTRACE_POKEDATA
 #define PT_WRITE_U		PTRACE_POKEUSER
