@@ -5,7 +5,7 @@ typedef void (*function)(void);
 #define NUM_ATEXIT	32
 
 static function __atexitlist[NUM_ATEXIT];
-static int atexit_counter = 0;
+static int atexit_counter;
 
 int atexit(function t) {
   if (atexit_counter<NUM_ATEXIT) {
@@ -17,12 +17,12 @@ int atexit(function t) {
 }
 
 extern void _exit(int code) __attribute__((noreturn));
-extern void __thread_doexit();
+extern void __thread_doexit(int doexit);
 
 void __libc_exit(int code);
 void __libc_exit(int code) {
   register int i=atexit_counter;
-  __thread_doexit();
+  __thread_doexit(code);
   while(i) {
     __atexitlist[--i]();
   }
