@@ -2,7 +2,7 @@
 #include <sys/types.h>
 
 speed_t cfgetospeed(struct termios *termios_p) {
-  return ((termios_p->c_iflag & (CBAUD|CBAUDEX)));
+  return ((termios_p->c_cflag & (CBAUD|CBAUDEX)));
 }
 
 speed_t cfgetispeed(struct termios *termios_p)	__attribute__((weak,alias("cfgetospeed")));
