@@ -11,5 +11,8 @@ char *strncpy(char *dest, const char *src, size_t n) {
   memset(dest,0,n);
 #endif
   memccpy(dest,src,0,n);
+#ifdef WANT_NON_COMPLIANT_STRNCAT
+  dest[n-1]=0;
+#endif
   return dest;
 }
