@@ -27,12 +27,11 @@ static int swrite(void*ptr, size_t nmemb, struct str_data* sd) {
 
 int vsnprintf(char* str, size_t size, const char *format, va_list arg_ptr) {
   long n;
-  struct str_data sd = { str, 0, size };
+  struct str_data sd = { str, 0, size?size-1:0 };
   struct arg_printf ap = { &sd, (int(*)(void*,size_t,void*)) swrite };
-  if (size) --sd.size;
   n=__v_printf(&ap,format,arg_ptr);
-  if (str) {
-    if ((long)n>(long)size) str[size]=0;
+  if (str && size && n>=0) {
+    if (size!=(size_t)-1 && ((size_t)n>=size)) str[size-1]=0;
     else str[n]=0;
   }
   return n;
