@@ -1,4 +1,5 @@
 #include <string.h>
+#include <strings.h>
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
@@ -32,7 +33,7 @@ int gethostbyname2_r(const char* name, int AF, struct hostent* result,
     while ((r=gethostent_r(buf,buflen))) {
       if (r->h_addrtype==AF) {
 	int i;
-	if (!strcmp(r->h_name,name)) {	/* found it! */
+	if (!strcasecmp(r->h_name,name)) {	/* found it! */
 found:
 	  memmove(result,r,sizeof(struct hostent));
 	  *RESULT=result;
@@ -42,7 +43,7 @@ found:
 	}
 	for (i=0; i<16; ++i) {
 	  if (r->h_aliases[i]) {
-	    if (!strcmp(r->h_aliases[i],name)) goto found;
+	    if (!strcasecmp(r->h_aliases[i],name)) goto found;
 	  } else break;
 	}
       }
