@@ -2,6 +2,6 @@
 
 char *setlocale (int category, const char *locale) {
   (void)category;
-  if (locale) return 0;
+  if (locale && (locale[0]!='C' || locale[1])) return 0;
   return "C";
 }
