@@ -50,6 +50,11 @@ int _dl_sys_fstat(int filedes, struct stat *buf);
 extern char*strdup(const char*s);
 extern void free(void*p);
 
+__attribute__((visibility("hidden")))
+unsigned long _dl_main(int argc,char*argv[],char*envp[],unsigned long _dynamic);
+__attribute__((visibility("hidden")))
+unsigned long do_resolve(struct _dl_handle*dh,unsigned long off);
+
 #if defined(__i386__)
 
 asm(".text \n"
@@ -180,26 +185,14 @@ static inline int work_on_pltgot(struct _dl_handle*dh) {
 
 #warning "x86_64 is not tested yet..."
 
-static unsigned long*x86_64__got=0;
-static unsigned long __start=(unsigned long)&_start;
-
 asm(".text \n"
 ".type _start,@function \n"
 "_start: \n"
 "	movq	%rsp,%rbp		# save stack \n"
 "	movq	(%rbp), %rdi		# argc \n"
-"	leaq	4(%rbp),%rsi		# argv \n"
+"	leaq	8(%rbp),%rsi		# argv \n"
 "	leaq	8(%rsi,%rdi,8),%rdx	# envp \n"
-/* get 'relocated' address of _DYNAMIC */
-"	leaq	_DYNAMIC@GOTPCREL(%rip), %rcx \n"
-"	subq	_DYNAMIC@GOT, %rcx \n"
-"	movq	%rcx, x86_64__got(%rip) # save got address \n"
-"	movq	(%rcx), %rcx \n"
-/* %rcx still needs the load-address added... */
-"	leaq	_start(%rip), %r8	#   relocated _start address \n"
-"	subq	__start(%rip), %r8	# unrelocated _start address \n"
-//"	movq	%r8, __loadaddr(%rip)	# save base address \n"
-"	addq	%r8, %rcx \n"
+"	leaq	_DYNAMIC(%rip), %rcx	# relocated address of _DYNAMIC \n"
 /* call _dl_main */
 "	call	_dl_main \n"
 /* restore stack */
@@ -290,7 +283,9 @@ asm(".text \n"
    );
 
 static inline unsigned long* get_got(void) {
-  return x86_64__got;
+  unsigned long*ret;
+  asm("lea _GLOBAL_OFFSET_TABLE_(%%rip),%0" : "=r"(ret) );
+  return ret;
 }
 
 static inline int work_on_pltgot(struct _dl_handle*dh) {
@@ -665,22 +660,23 @@ static char*_dl_lib_strdup(const char*s) {
   return ret;
 }
 
-#ifdef __GDB_SUPPORT__
-volatile void _dl_debug_state(void);
+#ifdef WANT_LD_SO_GDB_SUPPORT
 /* gdb debug break point */
-void _dl_debug_state() {}
+static volatile void _dl_debug_state(void) {
+#ifdef DEBUG
+  struct _dl_handle*tmp;
+  pf(__FUNCTION__); pf(": r_state "); ph(_r_debug.r_state); pf("\n");
+  for (tmp=_r_debug.r_map;tmp;tmp=tmp->next) {
+    pf("link_map "); ph((unsigned long)tmp);
+    pf(" l_addr "); ph((unsigned long)tmp->mem_base);
+    pf(" l_name "); pf(tmp->l_name ? tmp->l_name : "<null>");
+    pf(" l_ld "); ph((unsigned long)tmp->dynamic); pf("\n");
+  }
+#endif
+}
 
 /* gdb debug init stuff */
-struct r_debug _r_debug;
-static struct r_debug* _dl_debug_init(Elf_Addr dl_base) {
-  if (_r_debug.r_brk==0) {
-    _r_debug.r_version	= 1;
-    _r_debug.r_ldbase	= dl_base;
-    _r_debug.r_map	= _dl_root_handle;	/* this my be wrong */
-    _r_debug.r_brk	= (Elf_Addr)&_dl_debug_state;
-  }
-  return &_r_debug;
-}
+static struct r_debug _r_debug;
 #endif
 
 /* now reuse some unchanged sources */
@@ -688,6 +684,7 @@ static struct r_debug* _dl_debug_init(Elf_Addr dl_base) {
 #include "_dl_alloc.c"
 
 #include "dlsym.c"
+#include "dladdr.c"
 
 #include "_dl_search.c"
 
@@ -713,7 +710,7 @@ static void tt_fini(void) {
 static void _DIE_() { _dl_sys_exit(213); }
 
 /* lazy function resolver */
-static unsigned long do_resolve(struct _dl_handle*dh,unsigned long off) {
+unsigned long do_resolve(struct _dl_handle*dh,unsigned long off) {
   _dl_rel_t *tmp = ((void*)dh->plt_rel)+off;
   int sym=ELF_R_SYM(tmp->r_info);
   register unsigned long sym_val;
@@ -768,7 +765,6 @@ static struct _dl_handle*_dl_map_lib(const char*fn,const char*pathname,int fd,in
   Elf_Phdr*ld[4]={0,0,0,0};
   Elf_Phdr*dyn=0;
 
-  if (0) { pathname=0; }	/* no unused parameter */
   if (fd==-1) return 0;
 
   if (_dl_sys_fstat(fd,&st)<0) {
@@ -866,10 +862,13 @@ err_out_free:
 
   if (ret) {
     ++ret->lnk_count;
-    if (flags&RTLD_USER)
+    if (flags&RTLD_USER) {
+      ret->l_name=strdup(pathname);
       ret->name=strdup(fn);
-    else
+    } else {
+      ret->l_name=_dl_lib_strdup(pathname);
       ret->name=_dl_lib_strdup(fn);
+    }
     ret->flags=flags;
     ret->dynamic=(Elf_Dyn*)(m+dyn->p_vaddr);
   }
@@ -968,18 +967,21 @@ static struct _dl_handle* _dl_dyn_scan(struct _dl_handle*dh,Elf_Dyn*_dynamic) {
 
       /* BASIC RELOCATION */
     case DT_REL:
+    case DT_RELA:
       rel = (_dl_rel_t*)(dh->mem_base+_dynamic[i].d_un.d_val);
 #ifdef DEBUG
       pf(__FUNCTION__); pf(": have rel @ "); ph((long)rel); pf("\n");
 #endif
       break;
     case DT_RELENT:
+    case DT_RELAENT:
       relent=_dynamic[i].d_un.d_val;
 #ifdef DEBUG
       pf(__FUNCTION__); pf(": have relent  @ "); ph((long)relent); pf("\n");
 #endif
       break;
     case DT_RELSZ:
+    case DT_RELASZ:
       relsize=_dynamic[i].d_un.d_val;
 #ifdef DEBUG
       pf(__FUNCTION__); pf(": have relsize @ "); ph((long)relsize); pf("\n");
@@ -1081,7 +1083,7 @@ static struct _dl_handle* _dl_dyn_scan(struct _dl_handle*dh,Elf_Dyn*_dynamic) {
 #ifdef DEBUG
     pf(__FUNCTION__); pf(": rel plt/got\n");
 #endif
-    for(tmp=plt_rel;tmp<max;(char*)tmp=((char*)tmp)+sizeof(_dl_rel_t)) {
+    for(tmp=plt_rel;tmp<max;tmp=(void*)(((char*)tmp)+sizeof(_dl_rel_t))) {
       if ((dh->flags&RTLD_NOW)) {
 	unsigned long sym=(unsigned long)_dl_sym(dh,ELF_R_SYM(tmp->r_info));
 	if (sym) *((unsigned long*)(dh->mem_base+tmp->r_offset))=sym;
@@ -1116,6 +1118,14 @@ static void*_dl_load(const char*fn,const char*pathname,int fd,int flags) {
   struct _dl_handle*ret=0;
   if ((ret=_dl_map_lib(fn,pathname,fd,flags))) {
     ret=_dl_dyn_scan(ret,ret->dynamic);
+#ifdef WANT_LD_SO_GDB_SUPPORT
+    if (ret) {
+      _r_debug.r_state=RT_ADD;
+      _dl_debug_state();
+      _r_debug.r_state=RT_CONSISTENT;
+      _dl_debug_state();
+    }
+#endif
   }
   return ret;
 }
@@ -1252,7 +1262,7 @@ static void _dl_elfaux(register unsigned long*ui) {
 
 
 /* start of libdl dynamic linker */
-static unsigned long _dl_main(int argc,char*argv[],char*envp[],unsigned long _dynamic) {
+unsigned long _dl_main(int argc,char*argv[],char*envp[],unsigned long _dynamic) {
   unsigned long*got;
   struct _dl_handle*prog,*mydh;
   struct _dl_handle my_dh;
@@ -1277,6 +1287,7 @@ static unsigned long _dl_main(int argc,char*argv[],char*envp[],unsigned long _dy
   my_dh.mem_base=(char*)loadaddr;
   my_dh.mem_size=0;
   my_dh.lnk_count=1024;
+  my_dh.l_name=0; /* filled in later from PT_INTERP */
   my_dh.name="libdl.so";
   my_dh.flags=LDSO_FLAGS;
 
@@ -1318,7 +1329,9 @@ static unsigned long _dl_main(int argc,char*argv[],char*envp[],unsigned long _dy
   for(i=0;(i<prog_ph_num);++i) {
     if (prog_ph[i].p_type==PT_DYNAMIC) {
       prog_dynamic=(Elf_Dyn*)prog_ph[i].p_vaddr;
-      break;
+    }
+    if (prog_ph[i].p_type==PT_INTERP) {
+      mydh->l_name=(char*)prog_ph[i].p_vaddr;
     }
   }
   if (prog_dynamic==0) {
@@ -1326,6 +1339,7 @@ static unsigned long _dl_main(int argc,char*argv[],char*envp[],unsigned long _dy
     pf(" error with program: no dynamic section ?\n");
     return (unsigned long)_DIE_;
   }
+  prog->l_name=0;
   prog->name=0;
   prog->lnk_count=1024;
   prog->dynamic=prog_dynamic;
@@ -1340,6 +1354,24 @@ static unsigned long _dl_main(int argc,char*argv[],char*envp[],unsigned long _dy
     return (unsigned long)_DIE_;
   }
 
+#ifdef WANT_LD_SO_GDB_SUPPORT
+  _r_debug.r_version=1;
+  _r_debug.r_map=_dl_root_handle;
+  _r_debug.r_brk=(void*)&_dl_debug_state;
+  _r_debug.r_state=RT_CONSISTENT;
+  _r_debug.r_ldbase=loadaddr;
+  if (prog_dynamic) {
+    for (i=0;prog_dynamic[i].d_tag;++i)
+      if (prog_dynamic[i].d_tag==DT_DEBUG) {
+	prog_dynamic[i].d_un.d_ptr=(Elf_Addr)&_r_debug;
+#ifdef DEBUG
+	pf(__FUNCTION__); pf(": set DT_DEBUG @ "); ph(prog_dynamic[i].d_un.d_val); pf("\n");
+#endif
+      }
+  }
+  _dl_debug_state();
+#endif
+
   /* now start the program */
 #ifdef DEBUG
   pf(__FUNCTION__); pf(": now jump to program entrypoint\n");
