@@ -48,11 +48,12 @@ static int _dl_apply_relocate(struct _dl_handle*dh,_dl_rel_t*rel) {
   if (typ==R_386_32) {			/* 1 */
     *loc=(unsigned long)(dh->mem_base+dh->dyn_sym_tab[ELF_R_SYM(rel->r_info)].st_value);
   } else if (typ==R_386_COPY)  {	/* 5 */
-    int len=dh->dyn_sym_tab[ELF_R_SYM(rel->r_info)].st_size;
+    unsigned long len=dh->dyn_sym_tab[ELF_R_SYM(rel->r_info)].st_size;
+    void*from=_dl_sym_next(dh,ELF_R_SYM(rel->r_info));
 #ifdef DEBUG
-    pf(__FUNCTION__); pf(": R_386_COPY !\n");
+    pf(__FUNCTION__); pf(": R_386_COPY from "); ph((unsigned long)from); pf("\n");
 #endif
-    memcpy(loc,(void*)(unsigned long)_dl_sym(dh,ELF_R_SYM(rel->r_info)),len);
+    memcpy(loc,from,len);
   } else if (typ==R_386_GLOB_DAT) {	/* 6 */
     *loc=(unsigned long)_dl_sym(dh,ELF_R_SYM(rel->r_info));
   } else if (typ==R_386_JMP_SLOT) {	/* 7 */
@@ -67,11 +68,12 @@ static int _dl_apply_relocate(struct _dl_handle*dh,_dl_rel_t*rel) {
   if (typ==R_ARM_ABS32) {		/*  2 */
     *loc=(unsigned long)(dh->mem_base+dh->dyn_sym_tab[ELF_R_SYM(rel->r_info)].st_value);
   } else if (typ==R_ARM_COPY)  {	/* 20 */
-    int len=dh->dyn_sym_tab[ELF_R_SYM(rel->r_info)].st_size;
+    unsigned long len=dh->dyn_sym_tab[ELF_R_SYM(rel->r_info)].st_size;
+    void*from=_dl_sym_next(dh,ELF_R_SYM(rel->r_info));
 #ifdef DEBUG
-    pf(__FUNCTION__); pf(": R_ARM_COPY !\n");
+    pf(__FUNCTION__); pf(": R_ARM_COPY from "); ph((unsigned long)from); pf("\n");
 #endif
-    memcpy(loc,(void*)(unsigned long)_dl_sym(dh,ELF_R_SYM(rel->r_info)),len);
+    memcpy(loc,from,len);
   } else if (typ==R_ARM_GLOB_DAT) {	/* 21 */
     *loc=(unsigned long)_dl_sym(dh,ELF_R_SYM(rel->r_info));
   } else if (typ==R_ARM_JUMP_SLOT) {	/* 22 */
@@ -82,6 +84,28 @@ static int _dl_apply_relocate(struct _dl_handle*dh,_dl_rel_t*rel) {
   } else
     ret=1;
 #endif
+#ifdef __x86_64__
+  if (typ==R_X86_64_64) {			/* 1 */
+    *loc=(unsigned long)(dh->mem_base+dh->dyn_sym_tab[ELF_R_SYM(rel->r_info)].st_value);
+  } else if (typ==R_X86_64_COPY)  {	/* 5 */
+    unsigned long len=dh->dyn_sym_tab[ELF_R_SYM(rel->r_info)].st_size;
+    void*from=_dl_sym_next(dh,ELF_R_SYM(rel->r_info));
+#ifdef DEBUG
+    pf(__FUNCTION__); pf(": R_X86_64_COPY from "); ph((unsigned long)from); pf("\n");
+#endif
+    memcpy(loc,from,len);
+  } else if (typ==R_X86_64_GLOB_DAT) {	/* 6 */
+    *loc=(unsigned long)_dl_sym(dh,ELF_R_SYM(rel->r_info));
+  } else if (typ==R_X86_64_JUMP_SLOT) {	/* 7 */
+    *loc=((unsigned long)dh->mem_base)+rel->r_addend;
+  } else if (typ==R_X86_64_RELATIVE) {	/* 8 */
+    *loc=((unsigned long)dh->mem_base)+rel->r_addend;
+  } else if (typ==R_X86_64_32) {	/* 10 */
+    *loc=((unsigned long)(dh->mem_base+dh->dyn_sym_tab[ELF_R_SYM(rel->r_info)].st_value))&0xffffffffUL;
+  } else if (typ==R_X86_64_NONE) {	/* 0 */
+  } else
+    ret=1;
+#endif
 
 #ifdef DEBUG
   pf(__FUNCTION__); pf(": @ "); ph((unsigned long)loc); pf(" val "); ph(*(unsigned long*)loc); pf("\n");
