@@ -9,10 +9,10 @@ void *_dlsym(void* handle,const char* symbol) {
   unsigned long*sym=0;
   if (handle) {
     struct _dl_handle*dh=(struct _dl_handle*)handle;
-    unsigned long hash =elf_hash(symbol);
-    unsigned long bhash=hash%HASH_BUCKET_LEN(dh->hash_tab);
-    unsigned long*chain=HASH_CHAIN(dh->hash_tab);
-    unsigned long ind;
+    unsigned int hash =elf_hash(symbol);
+    unsigned int bhash=hash%HASH_BUCKET_LEN(dh->hash_tab);
+    unsigned int*chain=HASH_CHAIN(dh->hash_tab);
+    unsigned int ind;
     char *name=dh->dyn_str_tab;
 
 #ifdef DEBUG
@@ -27,10 +27,10 @@ void *_dlsym(void* handle,const char* symbol) {
     while(ind) {
       int ptr=dh->dyn_sym_tab[ind].st_name;
 #ifdef DEBUG
-//      pf(__FUNCTION__); pf(": symbol(\""); pf(name+ptr); pf("\",\"); pf(symbol); pf("\")\n");
+//      pf(__FUNCTION__); pf(": symbol(\""); pf(name+ptr); pf("\",\""); pf(symbol); pf("\")\n");
 #endif
-      if (strcmp(name+ptr,symbol)==0) {
-	if (ELF_ST_TYPE(dh->dyn_sym_tab[ind].st_shndx)!=0) {
+      if (strcmp(name+ptr,symbol)==0 && dh->dyn_sym_tab[ind].st_value!=0) {
+	if (dh->dyn_sym_tab[ind].st_shndx!=SHN_UNDEF) {
 	  sym=(long*)(dh->mem_base+dh->dyn_sym_tab[ind].st_value);
 	  break;	/* ok found ... */
 	}
@@ -47,13 +47,13 @@ void *_dlsym(void* handle,const char* symbol) {
 #ifdef __DIET_LD_SO__
 static
 #endif
-void*_dl_sym_search_str(struct _dl_handle*dh,char*name) {
+void*_dl_sym_search_str(struct _dl_handle*dh_begin,const char*name) {
   void *sym=0;
   struct _dl_handle*tmp;
 #ifdef DEBUG
   pf(__FUNCTION__); pf(": search for: "); pf(name); pf("\n");
 #endif
-  for (tmp=_dl_root_handle;tmp && (!sym);tmp=tmp->next) {
+  for (tmp=dh_begin;tmp && (!sym);tmp=tmp->next) {
 //    if (!(tmp->flags&RTLD_GLOBAL)) continue;
 #ifdef DEBUG
     pf(__FUNCTION__); pf(": searching in "); pf(tmp->name); pf("\n");
@@ -71,7 +71,19 @@ static
 #endif
 void*_dl_sym(struct _dl_handle*dh,int symbol) {
   char *name=dh->dyn_str_tab+dh->dyn_sym_tab[symbol].st_name;
-  void*sym=_dl_sym_search_str(dh,name);
+  void*sym=_dl_sym_search_str(_dl_root_handle,name);
+#ifdef DEBUG
+  pf(__FUNCTION__); pf(": "); ph(symbol); pf(" -> "); ph((long)sym); pf("\n");
+#endif
+  return sym;
+}
+
+#ifdef __DIET_LD_SO__
+static
+#endif
+void*_dl_sym_next(struct _dl_handle*dh,int symbol) {
+  char *name=dh->dyn_str_tab+dh->dyn_sym_tab[symbol].st_name;
+  void*sym=_dl_sym_search_str(dh->next,name);
 #ifdef DEBUG
   pf(__FUNCTION__); pf(": "); ph(symbol); pf(" -> "); ph((long)sym); pf("\n");
 #endif
