@@ -4,10 +4,7 @@
 #include <pthread.h>
 #include "thread_internal.h"
 
-int pthread_attr_getstackaddr(pthread_attr_t *attr, void **stack)
-{
-  __THREAD_INIT();
-
+int pthread_attr_getstackaddr(const pthread_attr_t*attr,void**stack) {
   *stack=attr->__stackaddr;
   return 0;
 }
