@@ -1,7 +1,8 @@
+#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <assert.h>
-#include <write12.h>
+#include <unistd.h>
 
 int compint(const void *a, const void *b) {
   register const int* A=a;
@@ -10,7 +11,7 @@ int compint(const void *a, const void *b) {
 }
 
 void die(const char* message) {
-  __write2(message);
+  write(2,message,strlen(message));
   exit(1);
 }
 
@@ -18,7 +19,6 @@ int main() {
 #define SIZE 1000
   int array[SIZE],array2[SIZE];
   int i,j;
-  long a,b,c;
   int *k;
   for (j=10; j<SIZE; ++j) {
     for (i=0; i<j; ++i) array[i]=rand();
@@ -28,14 +28,14 @@ int main() {
       if (array[i]<array[i+1])
 	die("not sorted after qsort!\n");
     for (i=0; i<j; ++i) {
-  //    printf("element %d: ",i);
+      printf("element %d: ",i);
       k=bsearch(array+i,array,j,sizeof(int),compint);
       if (!k) {
 	k=bsearch(array+i,array,j,sizeof(int),compint);
 	die("bsearch returned NULL\n");
       }
       if (k != array+i) die("bsearch found wrong element\n");
-  //    printf("%d\n",k-array);
+      printf("%d\n",k-array);
     }
   }
   return 0;
