@@ -259,8 +259,8 @@
 #define __NR_get_thread_area	211
 #define __NR_lookup_dcookie	212
 #define __NR_epoll_create	213
-#define __NR_epoll_ctl	214
-#define __NR_epoll_wait	215
+#define __NR_epoll_ctl	233
+#define __NR_epoll_wait	232
 #define __NR_remap_file_pages	216
 #define __NR_getdents64	217
 #define __NR_set_tid_address	218
@@ -280,6 +280,28 @@
 
 #define __NR_syscall_max __NR_exit_group
 
+#ifdef __PIC__
+#define syscall_weak(name,wsym,sym) \
+.text; \
+.type wsym,@function; \
+.weak wsym; \
+wsym: ; \
+.type sym,@function; \
+.global sym; \
+sym: \
+	mov	$__NR_##name,%al; \
+	jmp	__unified_syscall@PLT
+
+#define syscall(name,sym) \
+.text; \
+.type sym,@function; \
+.global sym; \
+sym: \
+	mov	$__NR_##name,%al; \
+	jmp	__unified_syscall@PLT
+
+#else
+
 #define syscall_weak(name,wsym,sym) \
 .text; \
 .type wsym,@function; \
@@ -298,4 +320,4 @@ sym: \
 sym: \
 	mov	$__NR_##name,%al; \
 	jmp	__unified_syscall
-
+#endif
